#!/sbin/sh
# Modular GApps Install Preparation Script

# Current FaceUnlock installed size (in Kbytes)
faceunlock_size_kb=16136

# Set to '0' since this install won't include Photosphere
photosphere_size_kb=0

# Buffer of extra system space to require for GApps install (10240=10MB)
# This will allow for some ROM size expansion when GApps are restored
buffer_size_kb=10240

# Parameters passed from updater-script
installing_gapps_type=$1
gapps_size_kb=$2
installing_gapps_version=$3
device_name=$4

# declare starting values
reclaimed_deleted_space_kb=0
reclaimed_gapps_space_kb=0
reclaimed_faceunlock_space_kb=0
reclaimed_photosphere_space_kb=0

echo -e "# begin pa gapps properties\n# This file contains information needed to flash PA GApps"  > /tmp/gapps.prop

# Determine if a GApps package is installed - the version, type, and whether it's a PA GApps package
if [ -e /system/priv-app/GoogleServicesFramework.apk ] && [ -e /system/priv-app/GoogleBackupTransport.apk ] && [ -e /system/priv-app/GoogleLoginService.apk ]; then
    if [ -f /system/etc/g.prop ]; then
        if (grep -qi "ro.addon.pa_version=" /system/etc/g.prop ); then
            echo -n "current_gapps_version=" >> /tmp/gapps.prop
            grep "^ro.addon.pa_version" /system/etc/g.prop | cut -d "=" -f2 >> /tmp/gapps.prop
            if (grep -qi "ro.addon.pa_type=" /system/etc/g.prop ); then
                echo -n "current_gapps_type=" >> /tmp/gapps.prop
                grep "^ro.addon.pa_type" /system/etc/g.prop | cut -d "=" -f2 >> /tmp/gapps.prop
            else
                echo "current_gapps_type=unknown" >> /tmp/gapps.prop
            fi
        else
            echo "current_gapps_version=unknown" >> /tmp/gapps.prop
            echo "current_gapps_type=unknown" >> /tmp/gapps.prop
         fi
    else
        echo "current_gapps_version=unknown" >> /tmp/gapps.prop
        echo "current_gapps_type=unknown" >> /tmp/gapps.prop
    fi
else
    echo "current_gapps_version=none" >> /tmp/gapps.prop
    echo "current_gapps_type=none" >> /tmp/gapps.prop
fi

echo "installing_gapps_version=$installing_gapps_version" >> /tmp/gapps.prop
echo -n -e "installing_gapps_type=$installing_gapps_type\ntotal_system_size_kb=" >> /tmp/gapps.prop

# I know it's not pretty, but it does get the job done
df -k system | grep '% /' | tr -cs '0-9' ' ' | sed 's/^[ \t]*//;s/[ \t]*$//' | sed 's/\(.*\) /\1+sys_pct=/' | sed 's/\(.*\) /\1+free_system_size_kb=/' | sed 's/\(.*\) /\1+used_system_size_kb=/' | sed 's/+/\n/g' | sed '/sys_pct/d' >> /tmp/gapps.prop

# Read list of files that are to be deleted
for deleted_file in $(cat /tmp/delete-list.txt)
do
    if [ -e $deleted_file ]; then
        file_size_kb=`du -k "$deleted_file" | cut -f1`
        reclaimed_deleted_space_kb=$(expr $file_size_kb + $reclaimed_deleted_space_kb)
    fi
done

# Read list of gapps files that are to be replaced
for gapps_file in $(cat /tmp/gapps-list.txt)
do
    if [ -e $gapps_file ]; then
        file_size_kb=`du -k "$gapps_file" | cut -f1`
        reclaimed_gapps_space_kb=$(expr $file_size_kb + $reclaimed_gapps_space_kb)
    fi
done

# Does device qualify for FaceUnlock?
good_ffc_device() {
  if [ -f /sdcard/.forcefaceunlock ]; then
    return 0
  fi
  if cat /proc/cpuinfo |grep -q Victory; then
    return 1
  fi
  if cat /proc/cpuinfo |grep -q herring; then
    return 1
  fi
  if cat /proc/cpuinfo |grep -q sun4i; then
    return 1
  fi
  return 0
}

# Final determination to decide if FaceUnlock should be installed
if good_ffc_device && [ -e /system/etc/permissions/android.hardware.camera.front.xml ]; then
    # Calculate space saved by removing existing FaceUnlock files
    faceunlock_file_list="/system/addon.d/71-faceunlock.sh
    /system/app/FaceLock.apk
    /system/lib/libfacelock_jni.so
    /system/vendor/pittpatt/models/detection/multi_pose_face_landmark_detectors.7/left_eye-y0-yi45-p0-pi45-r0-ri20.lg_32.bin
    /system/vendor/pittpatt/models/detection/multi_pose_face_landmark_detectors.7/nose_base-y0-yi45-p0-pi45-r0-ri20.lg_32.bin
    /system/vendor/pittpatt/models/detection/multi_pose_face_landmark_detectors.7/right_eye-y0-yi45-p0-pi45-r0-ri20.lg_32-2.bin
    /system/vendor/pittpatt/models/detection/yaw_roll_face_detectors.6/head-y0-yi45-p0-pi45-r0-ri30.4a-v24.bin
    /system/vendor/pittpatt/models/detection/yaw_roll_face_detectors.6/head-y0-yi45-p0-pi45-rn30-ri30.5-v24.bin
    /system/vendor/pittpatt/models/detection/yaw_roll_face_detectors.6/head-y0-yi45-p0-pi45-rp30-ri30.5-v24.bin
    /system/vendor/pittpatt/models/recognition/face.face.y0-y0-22-b-N.bin
    /system/app/FaceLock.odex"
    for faceunlock_file in $faceunlock_file_list
    do
    if [ -e $faceunlock_file ]; then
        file_size_kb=`du -k "$faceunlock_file" | cut -f1`
        reclaimed_faceunlock_space_kb=$(expr $file_size_kb + $reclaimed_faceunlock_space_kb)
    fi
    done
    inst_fu=true
else
    faceunlock_size_kb=0
    inst_fu=false
fi

# Calculate the total amount of system storage required for installation of GApps and options
total_gapps_size_kb=$(expr $gapps_size_kb + $faceunlock_size_kb + $photosphere_size_kb)

# Calculate the additional amount of system storage required for installation of GApps and options
free_space_reqd_kb=$(expr $gapps_size_kb + $faceunlock_size_kb + $photosphere_size_kb + $buffer_size_kb - $reclaimed_deleted_space_kb - $reclaimed_gapps_space_kb - $reclaimed_faceunlock_space_kb - $reclaimed_photosphere_space_kb)
if [ "$free_space_reqd_kb" -le "0" ]; then
    free_space_reqd_kb=0
fi

echo "free_space_reqd_kb=$free_space_reqd_kb" >> /tmp/gapps.prop
echo "total_gapps_size_kb=$total_gapps_size_kb" >> /tmp/gapps.prop
echo "install.chrome=false" >> /tmp/gapps.prop
echo "install.faceunlock=$inst_fu" >> /tmp/gapps.prop
echo "install.photosphere=false" >> /tmp/gapps.prop
echo "photosphere.device=none" >> /tmp/gapps.prop
echo "replace.launcher=false" >> /tmp/gapps.prop
echo "replace.mms=false" >> /tmp/gapps.prop
echo "replace.browser=false" >> /tmp/gapps.prop
echo "device_name=$device_name" >> /tmp/gapps.prop
echo "# end pa gapps properties" >> /tmp/gapps.prop

# Copy gapps.prop to the SDCard as 'pa_gapps.log'
cp -af /tmp/gapps.prop /sdcard/pa_gapps.log
